% Find the damping factor
function K = damping(area, ed, Q0,omega,q_previous,friction_model,friction_scaling,count)
% Input: 
% - Ai, Area of each section
% - epsilon/D, Roughness factor for each section
% - Q0, mean reference flow rate
% - 

% Output:
% - K, Damping factor

% constants:
g = 9.81;
rho = 1000;             
mu = 1.519*10^-3;   % at 5 deg
q_previous=abs(q_previous); % |q|

%Variables
D = sqrt(4*area/pi());
Qt = Q0*q_previous;

% Get the friction factor from the Moody diagram:
Reynolds = (rho * Qt * D)/(area * mu);

for Reynolds=NaN
    Reynolds=10^6;
end

% f = 1/(1.8*log10(6.9/Reynolds + (ed/3.7)^1.11))^2;
f=moody(ed,Reynolds);

%%%%%%%%%%%%%%%%%%%%%%%%NO FRICTION MODEL%%%%%%%%%%%%%%%%%%%%%%%%

if friction_model==1
    
K_I=0;
K_S=0;

end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%BROWNS MODEL%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Calculate the damping factors (according to ref. 11) 
%friction variable

if friction_model==2
    
%Define table and interpolate to find frictional value:
Re=[1250 2500 10^4 10^5 10^6 10^7 10^8];
fric_h=[4/3 1.113 1.049 1.020 1.012 1.008 1.000];
fric_var1=interp1(Re,fric_h,Reynolds);

lambda=4*f;
K_S=(4*lambda*Qt)/(pi()*D^3);

cut_off=0.01;
if omega<=cut_off
    K_I=0;
else if omega>cut_off
            K_I=(friction_scaling*fric_var1-1);
    end
end
K_I=1i*omega*K_I;
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%BREKKES MODEL 1984%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Calculate damping factors (according to ref. 11, eqn 67b):
if friction_model==3
lambda=4*f;

fric_var2=(Q0*q_previous)/(area*D*omega);

if fric_var2<0.1446535
    tau=(2.665-7.3*fric_var2)*rho*sqrt(omega*(mu/rho))*(Q0*q_previous)/area;
else
    tau=0.85*rho*((D*omega)^(1/3))*(sqrt(omega*mu/rho))*(Q0*q_previous/area)^(2/3);
end

K=(4*lambda*Qt)/(pi*D^3) + ((pi*D*tau)/(rho*Q0*q_previous));return

% K_S=(lambda*Qt)/(pi*D^3) + ((pi*D*tau)/(rho*Q0*q_previous))*cos(pi/4);
% K_I=1i*((pi*D*tau)/(rho*Q0*q_previous))*sin(pi/4);
    
end

%%%%%%%%%%%%%%%%%%%%%%BREKKES MODEL 1988%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Calculate damping factors (according to ref. 18):
if friction_model==4
lambda=4*f;

% K_r=(400/area)*((log(f)+5.977)/5.213)^5.155;
% Nikuradze's roughness:
K_r=sqrt(area/pi)*10^-(((0.5*(lambda^-0.5))-0.86));
fric_var3=(Q0*q_previous)/(area*K_r*omega);

if fric_var3>1.57
    f_d=exp(-5.977)+(5.213*(1/fric_var3)^0.194);
else
    f_d=0.4725/fric_var3;
end
f_d=abs(f_d)*cos(pi/8) + 1i*abs(f_d)*sin(pi/8);

tau_s=(2*lambda*rho*q_previous*Q0^2)/(8*area^2);
K_S=(tau_s*pi*D)/(rho*Q0*q_previous);

tau_d=0.5*f_d*((Q0*q_previous)/area)^2;
K_I=1i*(tau_d*pi*D)/(rho*Q0*q_previous);

% K_S=((pi*D)/(area^2))*((Qt*f)+(0.5*Q0*q_previous*f_d*cos(pi/8)));

% if omega<0.1
%     K_I=0;
% else
%     K_I=friction_scaling*((pi*D)/(area^2))*(0.5.*Q0*q_previous*f_d*cos(pi/8));
% end
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% if ed==0
%     K_S=0.00001;
%     K_I=0;
% end

K = K_S + K_I;return
end

