% Enkelt vannkraftsystem
% function hydropowersystem=hydropowersystem(Ta,Td,bt,bp,bs)
clear all;
clc;

governor='self-regulation';
compensator='none'; %none, araki, xinxin or murty
water_conduits='complete'; %penstock or complete
bode=1;         %1 for ON, 0 for OFF
rootlocus=0;    %1 for ON, 0 for OFF
nichols=0;      %1 for ON, 0 for OFF

%CONSTANTS
Q0=35;%!
H0=198;%!
A=30;%!
M=32;%!
g=9.81;%!
a=1200;%!
As=16;%!
Lt=4000;%!
V0=Q0/A;%!
At=0.0083*((M^2)*A^(5/3))/H0;

%CALCULATIONS
Tw=Q0/(g*H0)*((450/35)+(50/6.15)+(100/30)+(200/20)+(150/20))%!sum(L/A)
Tws=(As*H0)/Q0;
Twt=(Lt*V0)/(g*H0);
K=0.0001; %?
Tr=6.7;%!
Fn=1;
Td=8;%!
bt=0.8;%!
Ta=6.5;
bs=-0.6; % self-regulation
bp=0.0;  % statics
as=As/At

%%Compensator control parameters:
T1=1;
T2=100;
T3=10;
%%% PID regulation tuning (Hagihara et al (1979):
% KP = (4*Ta)/(5*Tw);
% KP/KI=Tw/3;
% KP/KD=3/Tw;

%%%Stein empirical regulation formulas:
%PI
% % % Gain=zeros(10,10);
% % % Phase=zeros(10,10);
% % % variable1=1:1:10;
% % % variable2=1:1:10;
% % % 
% % % for counter1=1:length(variable1)
% % %     for counter2=1:length(variable2)
% % % Td=variable1(counter1)*Tw;
% % % bt=variable2(counter2)*(Tw/Ta);

%PID
% Td=3*Tw;
% TN=0.5*Tw;
% KP=1.5*(Tw/Ta);
switch water_conduits
    case 'penstock'
        wc_num=[-Tw 1];
        wc_denom=[0.5*Tw 1];
    case 'complete'
        wc_num=[-Tw*Tws*Twt (Tws*Twt-K*Tws*Tw) (K*Tws-Twt-Tw) 1-K];
        wc_denom=[0.5*Tws*Twt*Tw (Tws*Twt-0.5*K*Tws*Tw) (K*Tws-0.5*Twt-0.5*Tw) 1-0.5*K];
end

 switch governor
    case 'pi'
        KP=Ta*bt*Td;
        TF_num=(1/KP)*conv([Td 1],[-Tw 1]);
        TF_denom=conv([0.5*Tw 1],[1 0 0]);
    case'pid'
        TF_num=conv([Td 1],[-Tw 1]);
        TF_denom=conv([0.5*Tw*Ta Ta 0],[bt*Td bp]);
    case 'self-regulation'
        
        switch compensator
            case 'araki'
                TF_denom=conv([0.5*Tw 1],[Ta Fn]);
            case 'shen'
                TF_denom=[0.1*Tr^2 0.5*Tw 1];
            case 'xinxin'
                compensator=conv([Td 1],conv([T2 1],[T3 1]))-[0 bt*T1*Td 0 0];
                TF_num=conv(compensator,wc_num);
                TF_denom=conv([T2 1],conv([T3 1],conv([Ta bs],conv(wc_denom,[bt*Td bp]))));
            case 'none'
                TF_num=conv([Td 1],wc_num);
                TF_denom=conv([Ta bs],conv(wc_denom,[bt*Td bp]));
        end
end

hd = tf(TF_num,TF_denom);
w=logspace(-3,1,1000);

%%plot
if bode==1
figure(1)
[Gm,Pm,Wg,Wp] = margin(hd);
% Gain(counter1,counter2)=db(Gm);
% Phase(counter1,counter2)=Pm;
margin(hd)
hold on;
end

% N=1/(1+hd);
% % [Closedloop_Gm,Closedloop_Pm,CLWg,CLWp] = margin(N); 
% margin(N)
% hold off;
if rootlocus==1
figure (2)
rlocus(hd);
hold on;
zero(hd);
hold off;
end

if nichols==1
figure(3)
nichols(hd)
end

% %%%Alternative plotting algorithm%%%
% figure(2)
% x=10^-3:1:10^1;
% y1=zeros(1,length(x));
% y2=-ones(1,length(x)).*180;
% 
% subplot(2,1,1)
% [amp0 phase0]=bode(TF_num, TF_denom, w);
% semilogx(w,20*log10(amp0),'LineWidth',2),grid;
% hold on;
% plot(x,y1,'black')
% set(get(1,'CurrentAxes'),'YTick',[-50 -40 -30 -10 0 10 20 30 40 50 60 70])
% set(get(1,'CurrentAxes'),'YLim',[-50 70])
% hold on;
% ylabel('Magnitude(dB)')
% title({['   b_{p}= ',num2str(bp),'   b_{s}= ',num2str(bs)];['T_{w}= ',num2str(Tw),'   T_{a}= ',num2str(Ta),'   T_{d}= ',num2str(Td),'   b_{p}= ',num2str(bp),'   b_{s}= ',num2str(bs),'   b_{t}= ',num2str(bt),'   T_{d}= ',num2str(Td)]},'FontWeight','bold')
% 
% N=1/(1+hd);
% % [Closedloop_Gm,Closedloop_Pm,CLWg,CLWp] = margin(N);
% [amp1 phase1]=bode(N,w);
% amp2=zeros(size(w));
% semilogx(w,20*log10(amp1(1,:)),'-.r','LineWidth',2)
% hold off;
% 
% subplot(2,1,2)
% semilogx(w,phase0-360,'LineWidth',2),grid
% hold on;
% plot(x,y2,'black')
% set(get(1,'CurrentAxes'),'YTick',[-270 -180 -135 -90 -45 0 90])
% set(get(1,'CurrentAxes'),'YLim',[-270 90])
% ylabel('Phase(deg)')

% figure(2)
% bode(TF_num, TF_denom, w)
