% Enkelt vannkraftsystem
%function hydropowersystem=hydropowersystem(Ta,Td,bt,bp,bs)
clear all;
clc;

governor='self-regulation';

%CONSTANTS
Q0=109;
H0=10;
L=30;
A=60;
g=9.81;
a=1200;
value=[10 12 14];

%CALCULATIONS
Tw=(Q0*L)/(g*H0*A)
Td=10;
bt=0.1;%value;
Ta=7.0;
bs=0.0; % self-regulation
bp=0.3;  % statics

for count=1:length(value)
    Td=value(count);

    switch governor
    case 'pi'
        KP=Ta*bt*Td;
        TF_num=(1/KP)*conv([Td 1],[-Tw 1]);
        TF_denom=conv([0.5*Tw 1],[1 0 0]);
    case'pid'
        TF_num=conv([Td 1],[-Tw 1]);
        TF_denom=conv([0.5*Tw*Ta Ta 0],[bt*Td bp]);
    case 'self-regulation'
        TF_num=conv([Td 1],[-Tw 1]);
        TF_denom=conv([Ta bs],conv([0.5*Tw 1],[bt*Td bp]));
    end

hd = tf(TF_num,TF_denom);
w=logspace(-3,1,1000);

%%plot
% figure(1)
% hd = tf(TF_num,TF_denom)
% [Gm,Pm,Wg,Wp] = margin(hd); 
% margin(hd)
% hold on;
% 
% N=1/(1+hd);
% % [Closedloop_Gm,Closedloop_Pm,CLWg,CLWp] = margin(N); 
% margin(N)
% hold off;
% 
% figure (2)
% rlocus(hd);
% hold on;
% zero(hd);
% hold off;
% 
% figure(3)
% nichols(hd)

% %%%Alternative plotting algorithm%%%
figure(1)
x=10^-3:1:10^1;
y1=zeros(1,length(x));
y2=-ones(1,length(x)).*180;

subplot(2,1,1)
[amp0 phase0]=bode(TF_num, TF_denom, w);
semilogx(w,20*log10(amp0),'b','LineWidth',2),grid;
hold on;
plot(x,y1,'black')
set(get(1,'CurrentAxes'),'YTick',[-50 -40 -30 -10 0 10 20 30 40 50 60 70])
set(get(1,'CurrentAxes'),'YLim',[-50 70])
hold on;
ylabel('Magnitude(dB)')
title({['   b_{p}= ',num2str(bp),'   b_{s}= ',num2str(bs)];['T_{w}= ',num2str(Tw),'   T_{a}= ',num2str(Ta),'   T_{d}= ',num2str(Td),'   b_{p}= ',num2str(bp),'   b_{s}= ',num2str(bs),'   b_{t}= ',num2str(bt),'   T_{d}= ',num2str(Td)]},'FontWeight','bold')
    
N=1/(1+hd);
% [Closedloop_Gm,Closedloop_Pm,CLWg,CLWp] = margin(N);
[amp1 phase1]=bode(N,w);
amp2=zeros(size(w));
semilogx(w,20*log10(amp1(1,:)),'-.r','LineWidth',2)
% hold off;

subplot(2,1,2)
semilogx(w,phase0-360,'b','LineWidth',2),grid;
hold on;
plot(x,y2,'black')
set(get(1,'CurrentAxes'),'YTick',[-270 -180 -135 -90 -45 0 90])
set(get(1,'CurrentAxes'),'YLim',[-270 90])
ylabel('Phase(deg)')
hold on;
end

% figure(2)
% bode(TF_num, TF_denom, w)
