% System definitions
clear all;
clc;

%%%%%%%%%%%%  choose system geometry and configurations   %%%%%%%%%%%%%%%%

system_geometry='aldal';          % "case2", "case3", "froland", "aldal" or "tyinoset", "kongsvinger","tafjord"
turbine='francis(joerundland)';          % "pelton", "francis1" or "francis(joerundland)"
response_type='n/nref';                % "n/nref", "p/pref", "h/y", "p/y" or "original" 
angle_handling='unwrap';            % "plain", "unwrap" or "unwrap_upper"
angleadjustment=-90;               % angle asjustment for plotting
friction_model=2;                   % 1 for no friction, 2 Brown, 3 for Brekke84 and 4 for Brekke88
friction_scaling=1;                 % scaling of the friction models

%governor settings
KP = 1.25;%10;
KI = 0.15625;%1;
KD = 0;
bt = 0.8;
Td = 8;%KP/KI;
bp = 0.0;
Tp = 0.0; 

value=[1 1 1];
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

countvalue=1000;
R9=zeros(countvalue,length(value));
theta9=zeros(countvalue,length(value));
omega=logspace(-3,1,countvalue);

        %System constants
        g=9.81;
        a=1200;
        
switch system_geometry
    case 'case2'
        Q0=20;
        H0=100;
        Qinit=[Q0 Q0];
        area=[20 20 20 20 20 20 20];
        L=[2586 500 10 10 10 10 10 ];
        ed=0.0001;
        
        getq=zeros(countvalue,2);
        getQ=ones(countvalue,2);
        double(getq);
        
    case 'case3'
        Q0=124;
        H0=580;
        Aeqv2=680;
        Aeqv9=0.001;
        Qinit=[Q0 0 Q0 Q0 Q0 Q0 Q0 Q0 0];
        area=[56.7 Aeqv2 50 60 20 80 20 20 Aeqv9];
        L=[6120 200 904 520 50 400 5 5 5];
        pipe_el=[ 1 90 45 45 0 0 90 0 90 ];
        
        getq=ones(countvalue,2,length(L));
        getQ=getq;
        
    case 'tafjord'
        % Sectional geomtrical constants for Tafjord
        Q0=8.8;
        H0=816.2;
        Aeqv2=0.0544;
        Aeqv9=0.001;
        A_drafttube=100;
        Qinit=[Q0 0 Q0 Q0 Q0 Q0 Q0 Q0 0];
        area=[ 11 Aeqv2 17.6 1.5 1.5 A_drafttube 0.0001 A_drafttube Aeqv9 ];
        L=[ 7567 7 50 176 5 50 1 50 1 ];
        pipe_el=[ 0 90 90 0 0 0 90 0 90 ];
        
        getq=zeros(countvalue,2,length(L));
        getQ=getq;
        
    case 'kongsvinger'
        % Sectional geomtrical constants for Kongsvinger
        Q0=108.5;
        H0=9.5;
        Aeqv2=39;
        Aeqv9=127;
        Qinit=[Q0 0 Q0 Q0 Q0 Q0 Q0 Q0 0];
        area=[ 150 Aeqv2 39 106 148 286 51 127 Aeqv9 ];
        L=[ 12 10 10 6 15 14 4 20.6 1 ];
        pipe_el=[ 0 90 90 0 0 0 90 0 90 ];
        
        %       M=[ 32 32 32 32 32 32 32 32 32 ];
        getq=zeros(countvalue,2,length(L));
        getQ=getq;
        
    case 'tyinoset'
        % Sectional geomtrical constants for Tyinoset
        Q0=30;
        H0=30;
        Aeqv2=20;
        Aeqv9=0.0001;
        Qinit=[Q0 0 Q0 Q0 Q0 Q0 Q0 Q0 0];
        area=[ 19.8 Aeqv2 19.8 7 19.8 19.8 19.8 19.8 Aeqv9 ];
        L=[ 2586 10 20 75 5 30 90 10 5 ];
        pipe_el=[ 0 90 90 30 0 0 90 0 90 ];
       
%       M=[ 32 32 32 32 32 32 32 32 32 ];
        getq=zeros(countvalue,2,length(L));
        getQ=getq;
        
    case 'froland'
        % Sectional geomtrical constants for Frland
        Q0=30;
        H0=158;             %Lowest waterlevel minus lower reservoir head
        Aeqv2=20;
        Aeqv9=0.001;
        Qinit=[Q0 0 Q0 Q0 Q0 Q0 Q0 Q0 0];
        area=[ 30 Aeqv2 30 30 30 30 30 20 Aeqv9 ];
        L=[ 5600 100 50 1500 50 5 100 200 50 ];
        pipe_el=[ 0 11 11 30 0 0 90 0 90 ];
        
%       M=[ 32 32 32 32 32 32 32 32 32 ];
        getq=zeros(countvalue,2,length(L));
        getQ=getq;
        
    case 'aldal'
        % Sectional geomtrical constants for Aldal
        Q0=35;
        H0=198;
        Aeqv2=102;
        Aeqv9=50;
        Qinit=[Q0 0 Q0 Q0 Q0 Q0 Q0 Q0 0];
        area=[ 30 Aeqv2 20 30 6.15 6.15 20 35 Aeqv9 ];
        L=[ 4000 150 200 1000 10 50 70 450 10 ];
        pipe_el=[ 0 11 90 30 0 0 90 0 90 ];
        
        %       M=[ 32 32 32 32 32 32 32 32 32 ];
        getq=zeros(countvalue,2,length(L));
        getQ=getq;
        
    case 'complex'
        % Sectional geomtrical constants for Tyinoset
        Q0=35;
        H0=198;
        Aeqv2=1;
        Aeqv9=1;
        Qinit=[Q0 0 0 0 Q0 0 0 0 Q0 Q0 Q0 Q0];
        area=[ 30 Aeqv2 30 30 30 Aeqv9 30 30 30 30 30 30 30 30 30 ];
        L=[ 1500 100 100 15 6000 5 100 460 50 ];
        pipe_el=[ 0 45 45 30 0 0 90 0 90 ];
        
        %       M=[ 32 32 32 32 32 32 32 32 32 ];
        getq=zeros(countvalue,2,length(L));
        getQ=getq;
    
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%Wait bar%%%%%%%%%%%%%%%%%
waiter=0;
hwbar = waitbar(0,'Please wait...','CreateCancelBtn','setappdata(gcbf,''cancelling'',true)');
setappdata(hwbar,'cancelling',false)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

for count=1:1:length(value)
%governor settings
KP = KP;
KI = KI;
KD = KD;
bt = bt;
Td = Td;
bp = bp;
Tp = Tp;  %time constant in electric hydraulic amplifier
%friction_scaling=value(count);

%FREQUENCY ANALYSIS ROUTINE
for counter=2:countvalue
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%Wait bar%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    waiter=waiter+1;
    if getappdata(hwbar,'cancelling');
        delete(hwbar)
        break
    end
    waitbar(waiter / (length(value)*countvalue),hwbar)
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    s=1i*omega(counter);
        
    switch system_geometry

    case 'case2'
        
        if counter==2
            getQ(counter-1,:)=Qinit(1);
            getQ(counter,:)=Qinit(1);
        end    
            for num=1:length(L)
                K(num)=damping(area(1),ed,Q0,omega(counter-1),getQ(counter-1,1)); %!
                z(num)=((s^2)+(K(num)*s))^0.5;
                hw(num)=(Q0*a)/(2*area(num)*g*H0);
                T(num)=s/(2*hw(num)*z(num)*tanh((L(num)*z(num))/a));
                S(num)=s/(2*hw(num)*z(num)*sinh((L(num)*z(num))/a));
            end
        
        
        case {'case3','tyinoset','aldal','froland','kongsvinger','tafjord'}
            
            %Surge shaft values
            H02=H0;
            H09=0;
            Aeqv2=area(2)/sin(pipe_el(2));
            Aeqv9=area(9)/sin(pipe_el(9));
            Q02=Q0;
            Q09=Q0;
            ed_hr=0.07; 
            ed_pt=0.0001;
            ed=[ed_hr ed_hr ed_hr ed_pt ed_hr ed_hr ed_hr ed_hr ed_hr];
            friction_scaling=value(count);
            
            if counter==2
                getQ(counter-1,:,:)=Qinit(1);
                getQ(counter,:,:)=Qinit(1);
            end
            
            for num=1:length(L)
                K(num)=damping(area(num),ed(num),Q0,omega(counter),getQ(counter-1,1,num),friction_model,friction_scaling,count); %!
                z(num)=((s^2)+(K(num)*s))^0.5;
                hw(num)=(Q0*a)/(2*area(num)*g*H0);
                T(num)=s/(2*hw(num)*z(num)*tanh((L(num)*z(num))/a));
                S(num)=s/(2*hw(num)*z(num)*sinh((L(num)*z(num))/a));
            end
            
        case 'complex'
                        %Surge shaft values
            H02=H0;
            H09=H0;
            Aeqv2=area(2)/sin(pipe_el(2));
            Aeqv6=area(6)/sin(pipe_el(6));
            Q02=Q0;
            Q06=Q0;
            ed=0.00001;
            
            if counter==2
                getQ(counter-1,:,:)=Qinit(1);
                getQ(counter,:,:)=Qinit(1);
            end
            
            for num=1:length(L)
                K(num)=damping(area(num),ed,Q0,omega(counter),getQ(counter-1,1,num),friction_model); %!
                z(num)=((s^2)+(K(num)*s))^0.5;
                hw(num)=(Q0*a)/(2*area(num)*g*H0);
                T(num)=s/(2*hw(num)*z(num)*tanh((L(num)*z(num))/a));
                S(num)=s/(2*hw(num)*z(num)*sinh((L(num)*z(num))/a));
                Kres(num)=0.0002; %
            end
    end
    
    % a PI-governor has the characteristics:          
    G=(1+Td*s)/(bt*Td*s);
%     G=KP+KI/s+KD*s;
    C=1/(1+Tp*s);
    E=-bp-(1/G);
    F=(G*bp+1)/(G*C);
    Kn=0;                   % open(0)/closed(1) loop
     
    % Turbine equations
    switch turbine
        case 'pelton1'
            Qn=0;
            Eq=0;
            En=0;
            Qy=1;
            Kq=1;
            Ta=6;
            
        case 'pelton(tafjord)'
            Qn=0;
            Eq=0;
            En=0;
            Qy=0.7;
            Kq=1;
            Ta=7.19;
            
        case 'kaplan'      %Kongsvinger kaplan turbine used
            eta = 0.913;    %efficiency
            n0 = 500;       %rev per min
            Qn = 0.55;
            Qy = 0.46;
            Eq = 0.113;
            En = -0.18;
            kq = 1.0;
            Ta= 4.8;
            
        case 'francis'      %Driva Francis turbine used
            eta = 0.928;     %efficiency
            Qn = -0.62;
            Qy = 1.0;
            Eq = -0.045;
            En = 0;
            kq = 1.16;
            Ta = 6.0;
            
        case 'francis(joerundland)'      %Driva Francis turbine used
            eta = 0.94;     %efficiency
            Qn = -0.55;
            Qy = 0.9;
            Eq = 0;
            En = 0;
            kq = 1.19;
            Ta = 6.5;
    end
    
    B5=0.5*(1-Qn);
    C5=Qy;
    J5=(3-En-(1+Eq)*Qn)/(2*(1+Eq));
    K5=Qn+En/(1+Eq);
    L5=Qy;
    M5=-1/(1+Eq);
    Q5=Qn;
   
    switch system_geometry
        % Matrix definitions
        case 'case1'
            %inititalize the matrices
            q=zeros(2,1);
            q(1)=1;
            A=[Kn E F; 0 1 0];
            

        case 'case2'
            q=zeros(7,1);
            q(3)=1;
            A=[-T(1) S(1) 0 0 0 0 0;
                S(1) -T(1)-B5 -Q5 0 -C5 0 B5;
                0 0 Kn E F 0 0;
                0 0 0 1 0 0 0;
                0 J5 K5 0 L5 M5 -J5;
                0 0 -Ta*s 0 0 1 0;
                0 B5 Q5 0 -C5 0 B5];
            
        case {'case3','tyinoset','aldal','froland','kongsvinger','tafjord'}
            q=zeros(9,1);
            
            switch response_type
                case {'n/nref','original'}
                    q(9)=1;
                    Kn=0;
                case 'p/pref'
                    q(8)=1;
                    Kn=1;           %closed(1) loop
                case 'p/y'
                    q(3)=1;
                    Kn=1;           %closed(1) loop
                case 'h/y'
                    q(3)=1;
                    Kn=1;           %closed(1) loop
            end
            
            A=[-T(3)-(s*H02*Aeqv2)/Q02 S(3) 0 0 0 0 0 0 0;
                S(3) -T(3)-T(4)-T(1) 0 S(4) 0 0 0 0 0;
                0 0 L5 -J5 J5 0 0 M5 K5;
                0 S(4) C5 -B5-T(4) B5 0 0 0 Q5;
                0 0 -C5 B5 -B5-T(6) S(6) 0 0 -Q5;
                0 0 0 0 S(6) -T(6)-T(7)-T(8) S(7) 0 0;
                0 0 0 0 0 S(7) -T(7)-((s*H09*Aeqv9)/Q09) 0 0
                0 0 0 0 0 0 0 1 -Ta*s
                0 0 F 0 0 0 0 0 Kn];
        
        case 'complex'
             q=zeros(15,1);
            
            switch response_type
                case {'n/nref','original'}
                    q(11)=1;
                    Kn=0;
                case 'p/pref'
                    q(12)=1;
                    Kn=1;           %closed(1) loop
                case 'p/y'
                    q(13)=1;
                    Kn=1;           %closed(1) loop
                case 'h/y'
                    q(10)=1;
                    Kn=1;           %closed(1) loop
            end
            
            A=[ 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0;
                0 1 0 0 0 0 0 0 0 0 0 0 0 0 0;
                0 0 -T(3)-(s*H02*Aeqv2)/Q02 S(3) 0 0 0 0 0 0 0 0 0 0 0;
                0 0 S(3) -T(3)-Kres(4) Kres(4) 0 0 0 0 0 0 0 0 0 0;
                0 0 0 Kres(4) -T(1)-Kres(4)-T(5) 0 0 S(5) 0 0 0 0 0 0 0;
                0 0 0 0 0 -T(7)-(s*H06*Aeqv6)/Q06 S(7) 0 0 0 0 0 0 0 0;
                0 0 0 0 0 S(7) -T(7)-Kres(8) Kres(8) 0 0 0 0 0 0 0;
                0 0 0 0 S(5) 0 Kres(8) -T(5)-Kres(8)-T(9) S(9) 0 0 0 0 0 0;
                0 0 0 0 0 0 0 S(9) -T(9)-Kres(10) Kres(10) 0 0 0 0 0;
                0 0 0 0 0 0 0 0 Kres(10) -Kres(10)-B5 Q5 0 -C5 0 B5;
                0 0 0 0 0 0 0 0 0 0 Kn E F 0 0;
                0 0 0 0 0 0 0 0 0 0 0 1 0 0 0;
                0 0 0 0 0 0 0 0 0 J5 K5 0 L5 M5 -J5;
                0 0 0 0 0 0 0 0 0 0 -Ta*s 0 0 1 0;
                0 0 0 0 0 0 0 0 0 B5 Q5 0 -C5 0 -B5-T(12)];
                
    end
   
    switch system_geometry
        case 'case1'
            % Get n/nref system response
            h=A\q;
            nspeed(counter)=h(1);
            frequency(counter)=omega(counter);
            
        case 'case2'
            % Get n/nref system response
            h=A\q;
            nspeed(counter)=h(3);
            frequency(counter)=omega(counter);
            
            % get the updated flow rates
            h_upd=[h(1) h(2)];
            A_upd= [-T(1) S(1);
                S(1) -T(1)];
            getq(counter,:)=A_upd*h_upd';
            getQ(counter,:)=[Qinit(1) Qinit(2)].*getq(counter,:)+[Qinit(1) Qinit(2)];
            
        case {'case3','tyinoset','aldal','froland','kongsvinger','tafjord'}
            % Get system response
            h=A\q;
            dampingfactor(counter)=abs(K(1));
            dampingfactorimag(counter)=imag(K(1));
            dampingfactorreal(counter)=real(K(1));
            dampingfactor2(counter)=K(4);
            dampingfactor2imag(counter)=imag(K(4));
            dampingfactor2real(counter)=real(K(4));
            switch response_type
                case {'n/nref','original'}
                    nspeed(counter)=h(9); % measuring point n
                case {'p/pref','p/y'}
                    nspeed(counter)=h(8); % measuring point p
                case 'h/y'
                    nspeed(counter)=h(4); % measurement point at 6
            end
            
            frequency(counter)=omega(counter);
            
            % get the updated flow rates
    
            h_upd=ones(length(L),2);
            A_upd=ones(2,2,length(L));
            
            h_upd(1,:)=[h(1) h(2)];
            A_upd(:,:,1)= [-T(3) S(3);
                      S(3) -T(3)];
            h_upd(4,:)=[h(2) h(4)];
            A_upd(:,:,4)= [-T(3) S(3);
                      S(3) -T(3)];
            h_upd(6,:)=[h(3) h(7)];
            A_upd(:,:,6)= [-T(6) S(6);
                      S(6) -T(6)];
            h_upd(7,:)=[h(3) h(7)];
            A_upd(:,:,7)= [-T(6) S(6);
                      S(6) -T(6)];
            
            getq(counter,:,1)=A_upd(:,:,1)*h_upd(1,:)';
            getq(counter,:,4)=A_upd(:,:,4)*h_upd(4,:)';
            getq(counter,:,6)=A_upd(:,:,6)*h_upd(6,:)';
            getq(counter,:,7)=A_upd(:,:,7)*h_upd(7,:)';
            
            getQ(counter,:,1)=[Qinit(1) Qinit(2)].*getq(counter,:,1)+[Qinit(1) Qinit(2)];
            getQ(counter,:,4)=[Qinit(2) Qinit(4)].*getq(counter,:,2)+[Qinit(2) Qinit(4)];
            getQ(counter,:,6)=[Qinit(5) Qinit(6)].*getq(counter,:,3)+[Qinit(5) Qinit(6)];
            getQ(counter,:,7)=[Qinit(6) Qinit(7)].*getq(counter,:,4)+[Qinit(6) Qinit(7)];
            
        case 'complex'
            
            h=A\q;
            dampingfactor(counter)=K(1);
            dampingfactor2(counter)=K(9);
            switch response_type
                case {'n/nref','original'}
                    nspeed(counter)=h(11); % measuring point n
                case {'p/pref','p/y'}
                    nspeed(counter)=h(12); % measuring point p
                case 'h/y'
                    nspeed(counter)=h(10); % measurement point at 6
            end
            
            frequency(counter)=omega(counter);
            
            % get the updated flow rates
    
            h_upd=ones(length(L),2);
            A_upd=ones(2,2,length(L));
            
            h_upd(1,:)=[h(1) h(7)];
            A_upd(:,:,1)= [-T(1) S(1);
                      S(1) -T(1)];
            h_upd(5,:)=[h(5) h(8)];
            A_upd(:,:,5)= [-T(5) S(5);
                      S(5) -T(5)];
            h_upd(9,:)=[h(8) h(9)];
            A_upd(:,:,9)= [-T(9) S(9);
                      S(9) -T(9)];
            h_upd(7,:)=[h(6) h(7)];
            A_upd(:,:,12)= [-T(7) S(7);
                      S(7) -T(7)];
            
            getq(counter,:,1)=A_upd(:,:,1)*h_upd(1,:)';
            getq(counter,:,2)=A_upd(:,:,5)*h_upd(5,:)';
            getq(counter,:,3)=A_upd(:,:,9)*h_upd(9,:)';
            getq(counter,:,4)=A_upd(:,:,12)*h_upd(12,:)';
            
            getQ(counter,:,1)=[Qinit(1) Qinit(7)].*getq(counter,:,1)+[Qinit(1) Qinit(7)];
            getQ(counter,:,5)=[Qinit(5) Qinit(8)].*getq(counter,:,2)+[Qinit(5) Qinit(8)];
            getQ(counter,:,9)=[Qinit(10) Qinit(11)].*getq(counter,:,3)+[Qinit(10) Qinit(11)];
            getQ(counter,:,7)=[Qinit(8) Qinit(9)].*getq(counter,:,4)+[Qinit(8) Qinit(9)];

end

x=10^-3:1:10^1;
y1=zeros(1,length(x));
y2=-ones(1,length(x)).*180;
end

%%%%%%%%%%%%%%%%%%%%% gain and phase values %%%%%%%%%%%%%%%%%%%%
R9(:,count) = db(abs(nspeed));                                                %Gain in dB (20*log(abs(nspeed))
switch angle_handling                                                             %adjustment for Matlabs handling of angles
    
    case 'unwrap'
        theta9(:,count) = (180/pi)*unwrap(angle(nspeed));                %get phase angle in degrees
    
    case 'unwrap_upper'
        for index=1:countvalue/2
            theta9(index,count) = (180/pi)*(angle(nspeed(index)));                %get phase angle in degrees
        end
        for index=countvalue/2:countvalue
            theta9(index,count) = (180/pi)*unwrap(angle(nspeed(index)));                %get phase angle in degrees
        end
        
    case 'plain'
        theta9(:,count) = (180/pi)*(angle(nspeed));
        
end
theta9(:,count) = theta9(:,count)+angleadjustment;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%% Find gain and phase margins%%%%%%%%%%%%%%%%
[valueR9, index_phasemarg] = min(abs(R9(2:end,count)));
[valuetheta9, index_gainmarg] = min(abs(theta9(2:end,count)+180));

if min(theta9(2:end,count)+180)<0 && max(theta9(2:end,count)+180)>0
    gainmargin(count)=-R9(index_gainmarg,count);
else
    gainmargin(count)=NaN;
end

if min(R9(2:end,count))<0 && max(R9(2:end,count))>0
    phasemargin(count)=180+theta9(index_phasemarg,count);
else
    phasemargin(count)=NaN;
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

end

close(hwbar)

%PLOTS
    switch response_type
    case 'original'
        %BODE PLOT
        figure(1)
        subplot(2,1,1)
        semilogx(frequency,R9(:,1),'b',frequency,R9(:,2),'g',frequency,R9(:,3),'r','LineWidth',2)
        hold on;
        plot(x,y1,'black'),grid;
        set(get(1,'CurrentAxes'),'YTick',[-200 -150 -100 -50 0 50 100 150 200])
        set(get(1,'CurrentAxes'),'YLim',[-200 200])
        title([' Kn=', num2str(Kn),', b_p=',num2str(bp),', KI=',num2str(KI),', b_t=',num2str(bt),', T_d=',num2str(Td),', T_p=',num2str(Tp)],'FontSize',16)
        legend1=legend([' K_P=',num2str(value(1))],[' K_P=',num2str(value(2))],[' K_P=',num2str(value(3))]);
        set(legend1,'Location','NorthEast')
        ylabel('Gain(dB)','FontSize',16)
        subplot(2,1,2)
        semilogx(frequency,theta9(:,1),'b',frequency,theta9(:,2),'g',frequency,theta9(:,3),'r','LineWidth',2), grid;
        set(get(1,'CurrentAxes'),'YTick',[-270 -225 -180 -135 -90 -45 0 90])
        set(get(1,'CurrentAxes'),'YLim',[-270 90])
        legend1=legend([' K_P=',num2str(value(1))],[' K_P=',num2str(value(2))],[' K_P=',num2str(value(3))]);
        set(legend1,'Location','NorthEast')
        hold on;
        plot(x,y2,'black')
        ylabel('Phase(deg)','FontSize',16)
        
        %NICHOLS PLOT
        figure(2)
        % hold on;
        plot(theta9(:,1),R9(:,1),'b',theta9(:,2),R9(:,2),'g',theta9(:,3),R9(:,3),'r')
        ngrid
        hold on;
        title([' Kn=', num2str(Kn),', b_p=',num2str(bp),', KI=',num2str(KI),', b_t=',num2str(bt),', T_d=',num2str(Td),', T_p=',num2str(Tp)])
        legend2=legend([' K_P=',num2str(value(1))],[' K_P=',num2str(value(2))],[' K_P=',num2str(value(3))]);
        set(legend2,'Location','SouthEast')
        xlabel('Phase(deg)','FontSize',16)
        ylabel('Gain(dB)','FontSize',16)
        
    case 'n/nref'
        %BODE PLOT
        figure(1)
        subplot(2,1,1)
        semilogx(frequency,R9(:,1),'b',frequency,R9(:,2),'g',frequency,R9(:,3),'r','LineWidth',2)
        hold on;
        plot(x,y1,'black'),grid;
        set(get(1,'CurrentAxes'),'YTick',[-200 -150 -100 -50 0 50 100 150 200])
        set(get(1,'CurrentAxes'),'YLim',[-200 200])
        title({['Plant: ',num2str(system_geometry),'   Turbine: ',num2str(turbine),'   (n/nref response)']; [' Kn=', num2str(Kn),', b_p=',num2str(bp),', KI=',num2str(KI),', b_t=',num2str(bt),', T_d=',num2str(Td),', T_p=',num2str(Tp)]},'FontWeight','bold','FontSize',10)
        legend1=legend([' ed=',num2str(value(1)),',  \DeltaK=',num2str(gainmargin(1))],[' ed=',num2str(value(2)) ',  \DeltaK=',num2str(gainmargin(2))],[' ed=',num2str(value(3)) ',  \DeltaK=',num2str(gainmargin(3))]);
        set(legend1,'Location','Northeast')
        ylabel('Gain(dB)','FontSize',16)
        subplot(2,1,2)
        semilogx(frequency,theta9(:,1),'b',frequency,theta9(:,2),'g',frequency,theta9(:,3),'r','LineWidth',2), grid;
        set(get(1,'CurrentAxes'),'YTick',[-360 -270 -225 -180 -135 -90 -45 0])
        set(get(1,'CurrentAxes'),'YLim',[-360 0])
        legend1=legend([' ed=',num2str(value(1)),',  \Psi=',num2str(phasemargin(1))],[' ed=',num2str(value(2)) ',  \Psi=',num2str(phasemargin(2))],[' ed=',num2str(value(3)) '  \Psi=',num2str(phasemargin(3))]);
        set(legend1,'Location','NorthEast')
        pmargin=legend([' \Psi=',num2str(phasemargin(1))],[' \Psi=',num2str(phasemargin(2))],[' \Psi=',num2str(phasemargin(3))]);
        set(pmargin,'Location','SouthEast')
        hold on;
        plot(x,y2,'black')
        ylabel('Phase(deg)','FontSize',16)
        
        %NICHOLS PLOT
        figure(2)
        plot(theta9(:,1),R9(:,1),'b',theta9(:,2),R9(:,2),'g',theta9(:,3),R9(:,3),'r')
        ngrid
        hold on;
        title([' Kn=', num2str(Kn),', b_p=',num2str(bp),', KI=',num2str(KI),', b_t=',num2str(bt),', T_d=',num2str(Td),', T_p=',num2str(Tp)])
        legend2=legend([' K_P=',num2str(value(1))],[' K_P=',num2str(value(2))],[' K_P=',num2str(value(3))]);
        set(legend2,'Location','SouthEast')
        xlabel('Phase(deg)','FontSize',16)
        ylabel('Gain(dB)','FontSize',16)
        hold off;
        
        %FRICTIONAL DAMPING PLOT
        
        figure(3)
        semilogx(frequency,dampingfactor,'b')
        hold on;
        semilogx(frequency,dampingfactorreal,'--r')
        hold on;
        semilogx(frequency,dampingfactorimag,'--g')
        title('Frictional damping, K','FontWeight','bold','FontSize',16)
        xlabel('Frequency, Hz','FontSize',16)
        ylabel('Frictional damping','FontSize',16)
        legend1=legend(' Total','Real','Imaginary','FontSize',8);
        set(legend1,'Location','NorthEast')
        hold off;
        
        
    case 'p/pref'
        %BODE PLOT
        figure(1)
        subplot(2,1,1)
        semilogx(frequency,R9(:,1),'b',frequency,R9(:,2),'g',frequency,R9(:,3),'r','LineWidth',2)
        hold on;
        plot(x,y1,'black'),grid;
        set(get(1,'CurrentAxes'),'YTick',[-200 -150 -100 -50 0 50 100 150 200])
        set(get(1,'CurrentAxes'),'YLim',[-200 200])
        title({['Plant: ',num2str(system_geometry),'   Turbine: ',num2str(turbine),'   (p/pref response)']; [' K_n=',num2str(Kn),' b_p=',num2str(bp),', KI=',num2str(KI),', b_t=',num2str(bt),', T_d=',num2str(Td),', T_p=',num2str(Tp)]},'FontWeight','bold','FontSize',10)
        %legend1=legend([' ed=',num2str(value(1)),',  \DeltaK=',num2str(gainmargin(1))],[' ed=',num2str(value(2)) ',  \DeltaK=',num2str(gainmargin(2))],[' ed=',num2str(value(3)) ',  \DeltaK=',num2str(gainmargin(3))],'FontSize',8);
        %set(legend1,'Location','Northeast')
        ylabel('Gain(dB)','FontSize',16)
        subplot(2,1,2)
        semilogx(frequency,theta9(:,1),'b',frequency,theta9(:,2),'g',frequency,theta9(:,3),'r','LineWidth',2), grid;
        set(get(1,'CurrentAxes'),'YTick',[-270 -225 -180 -135 -90 -45 0 90])
        set(get(1,'CurrentAxes'),'YLim',[-270 90])
        %legend1=legend([' ed=',num2str(value(1)),',  \Psi=',num2str(phasemargin(1))],[' ed=',num2str(value(2)) ',  \Psi=',num2str(phasemargin(2))],[' ed=',num2str(value(3)) '  \Psi=',num2str(phasemargin(3))],'FontSize',8);
        %set(legend1,'Location','NorthEast')
        hold on;
        plot(x,y2,'black')
        ylabel('Phase(deg)','FontSize',16)
        
        figure(2)
        semilogx(frequency,abs(dampingfactor),'b')
        title('Frictional damping, K','FontWeight','bold','FontSize',16)
        xlabel('Frequency, Hz','FontSize',16)
        ylabel('Frictional damping','FontSize',16)
        hold off;
        
        figure(3)
        semilogx(frequency(20:1000),abs(dampingfactor2(20:1000)),'b')
        title('Frictional damping at downstream surge shaft, K','FontWeight','bold','FontSize',16)
        xlabel('Frequency, Hz','FontSize',16)
        ylabel('Frictional damping','FontSize',16)
        hold off;
        
     case 'p/y'
        %BODE PLOT
        figure(1)
        subplot(2,1,1)
        semilogx(frequency,R9(:,1),'b',frequency,R9(:,2),'g',frequency,R9(:,3),'r','LineWidth',2)
        hold on;
        plot(x,y1,'black'),grid;
        set(get(1,'CurrentAxes'),'YTick',[-200 -150 -100 -50 0 50 100 150 200])
        set(get(1,'CurrentAxes'),'YLim',[-200 200])
        title({['Plant: ',num2str(system_geometry),'   Turbine: ',num2str(turbine),'   (p/y response)']; [' Kn=', num2str(Kn),', b_p=',num2str(bp),', KI=',num2str(KI),', b_t=',num2str(bt),', T_d=',num2str(Td),', T_p=',num2str(Tp)]},'FontWeight','bold','FontSize',10)
        legend1=legend([' ed=',num2str(value(1)),',  \DeltaK=',num2str(gainmargin(1))],[' ed=',num2str(value(2)) ',  \DeltaK=',num2str(gainmargin(2))],[' ed=',num2str(value(3)) ',  \DeltaK=',num2str(gainmargin(3))]);
        set(legend1,'Location','Northeast','FontSize',8)
        ylabel('Gain(dB)','FontSize',16)
        subplot(2,1,2)
        semilogx(frequency,theta9(:,1),'b',frequency,theta9(:,2),'g',frequency,theta9(:,3),'r','LineWidth',2), grid;
        set(get(1,'CurrentAxes'),'YTick',[-270 -225 -180 -135 -90 -45 0 90])
        set(get(1,'CurrentAxes'),'YLim',[-270 90])
        legend1=legend([' ed=',num2str(value(1)),',  \Psi=',num2str(phasemargin(1))],[' ed=',num2str(value(2)) ',  \Psi=',num2str(phasemargin(2))],[' ed=',num2str(value(3)) '  \Psi=',num2str(phasemargin(3))]);
        set(legend1,'Location','NorthEast','FontSize',8)
        hold on;
        plot(x,y2,'black')
        ylabel('Phase(deg)','FontSize',16)
        
        figure(2)
        semilogx(frequency,dampingfactor,'b')
        title('Frictional damping, K','FontWeight','bold','FontSize',16)
        xlabel('Frequency, Hz','FontSize',16)
        ylabel('Frictional damping','FontSize',16)
        hold off;


    case 'h/y'
        %BODE PLOT
        figure(1)
        subplot(2,1,1)
        semilogx(frequency,R9(:,1),'b',frequency,R9(:,2),'g',frequency,R9(:,3),'r','LineWidth',2)
        hold on;
        plot(x,y1,'black'),grid;
        hold on;
        set(get(1,'CurrentAxes'),'YTick',[-200 -150 -100 -50 0 50 100 150 200])
        set(get(1,'CurrentAxes'),'YLim',[-200 200])
        title({['Plant: ',num2str(system_geometry),'   Turbine: ',num2str(turbine),'   (h/y response)']; [' Kn=', num2str(Kn),', b_p=',num2str(bp),', KI=',num2str(KI),', b_t=',num2str(bt),', T_d=',num2str(Td),', T_p=',num2str(Tp)]},'FontWeight','bold','FontSize',10)
        legend1=legend([' ed=',num2str(value(1)),',  \DeltaK=',num2str(gainmargin(1))],[' ed=',num2str(value(2)) ',  \DeltaK=',num2str(gainmargin(2))],[' ed=',num2str(value(3)) ',  \DeltaK=',num2str(gainmargin(3))],'FontSize',8);
        set(legend1,'Location','Northeast')
        ylabel('Gain(dB)','FontSize',16)
        subplot(2,1,2)
        semilogx(frequency,theta9(:,1),'b',frequency,theta9(:,2),'g',frequency,theta9(:,3),'r','LineWidth',2), grid;
        set(get(1,'CurrentAxes'),'YTick',[-360 -270 -225 -180 -135 -90 -45 0])
        set(get(1,'CurrentAxes'),'YLim',[-360 90])
        legend1=legend([' ed=',num2str(value(1)),',  \Psi=',num2str(phasemargin(1))],[' ed=',num2str(value(2)) ',  \Psi=',num2str(phasemargin(2))],[' ed=',num2str(value(3)) '  \Psi=',num2str(phasemargin(3))],'FontSize',8);
        set(legend1,'Location','NorthEast')
        hold on;
        plot(x,y2,'black')
        ylabel('Phase(deg)','FontSize',16)
        
        figure(2)
        subplot(2,2,[1 3])
        semilogx(frequency,dampingfactor,'b')
        hold on;
        semilogx(frequency,dampingfactorreal,'--r')
        hold on;
        semilogx(frequency,dampingfactorimag,'--g')
        set(get(1,'CurrentAxes'),'XLim',[10^-3 10^1])
        title('Head race channel','FontWeight','bold','FontSize',16)
        xlabel('Frequency, Hz','FontSize',16)
        ylabel('Frictional damping','FontSize',16)
        legend1=legend(' Total','Real','Imaginary','FontSize',16);
        set(legend1,'Location','NorthWest')
        
        subplot(2,2,[2 4])
        semilogx(frequency,dampingfactor2,'b')
        hold on;
        semilogx(frequency,dampingfactor2real,'--r')
        hold on;
        semilogx(frequency,dampingfactor2imag,'--g')
        set(get(1,'CurrentAxes'),'XLim',[10^-3 10^1])
        title('Surge shaft channel','FontWeight','bold','FontSize',16)
        xlabel('Frequency, Hz','FontSize',16)
        ylabel('Frictional damping','FontSize',16)
        legend1=legend(' Total','Real','Imaginary','FontSize',16);
        set(legend1,'Location','NorthWest')
        hold off;
end

% legend1=legend([' b_p=',num2str(value(1))],[' b_p=',num2str(value(2))],[' b_p=',num2str(value(3))]);
% set(legend1,'Location','NorthEast')
% hold on;
% plot(x,y2,'black--')
% ylabel('Phase(deg)')

% Waitbar closing
switch system_geometry
    case 'kongsvinger'
        switch response_type
            case {'p/pref', 'p/y'}
                run kongsvinger_freqresponse
        end
    case 'tafjord'
        switch response_type
            case {'p/pref', 'p/y','h/y'}
                run tafjord_freqresponse
        end
end

F = findall(0,'type','figure','tag','TMWWaitbar');
delete(F);

